@@ -214,13 +214,6 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     # Reemplazo [NULL] con NaN.
     Portafolio = Portafolio.replace("[NULL]", np.nan)
     Portafolio = Portafolio.replace('NA', np.nan)
-
-    ########################################################################################################################
-    # Agrego portfolioNAV
-    Portafolio['portfolioNAV'] = Portafolio['mktValue'].sum()
-    # Añadir diferenciación en base a cada portafolio dentro del archivo unico 351.
-    ########################################################################################################################
-    
     
     # Cruzo con archivo NEMOS-ISIN.xlsx - SI ES IBR.
     Nemos.rename(columns={'NEMO NUEVO': 'assetId', 'USO TASA ACTUAL': 'cpnFirstActual', 'TIPO TASA': 'cpnRateType', 'TASA REFERENCIA': 'indexRate_Nemo'}, inplace=True)
@@ -297,6 +290,12 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
 
     Portafolio['portfolioName'] = portfolioName
 
+    # Agrego portfolioNAV
+    df_NAV = Portafolio.groupby('subGroup').agg(portfolioNAV=('mktValue', 'sum')).reset_index()
+    Portafolio['portfolioNAV'] = np.nan
+    Portafolio['portfolioNAV'] = Portafolio['portfolioNAV'].fillna(Portafolio['subGroup'].map(df_NAV.set_index('subGroup')['portfolioNAV']))
+
+
     # Ajuste YTM
     Portafolio['yieldToMaturity'] = np.where(Portafolio['valuationMethod']==9, Portafolio['discountRate'], Portafolio['yieldToMaturity'])
 
